
From: Christoph Lameter <christoph@graphe.net>

This patch removes the check for the existence of multiple HPET timers.  It
allows the use of HPET with only a single timer for system time if
HPET_EMULATE_RTC is not set.

Signed-off-by: Christoph Lameter <christoph@lameter.com>
Signed-off-by: Shai Fultheim <Shai@Scalex86.org>
Acked-by: "Pallipadi, Venkatesh" <venkatesh.pallipadi@intel.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/kernel/time_hpet.c |   13 +++++++++----
 1 files changed, 9 insertions(+), 4 deletions(-)

diff -puN arch/i386/kernel/time_hpet.c~support-hpet-with-a-single-timer-for-system-time arch/i386/kernel/time_hpet.c
--- 25/arch/i386/kernel/time_hpet.c~support-hpet-with-a-single-timer-for-system-time	2005-03-07 20:41:31.000000000 -0800
+++ 25-akpm/arch/i386/kernel/time_hpet.c	2005-03-07 20:41:31.000000000 -0800
@@ -121,11 +121,16 @@ int __init hpet_enable(void)
 	id = hpet_readl(HPET_ID);
 
 	/*
-	 * We are checking for value '1' or more in number field.
-	 * So, we are OK with HPET_EMULATE_RTC part too, where we need
-	 * to have atleast 2 timers.
+	 * We are checking for value '1' or more in number field if
+	 * CONFIG_HPET_EMULATE_RTC is set because we will need an
+	 * additional timer for RTC emulation.
+	 * However, we can do with one timer otherwise using the
+	 * the single HPET timer for system time.
 	 */
-	if (!(id & HPET_ID_NUMBER) ||
+	if (
+#ifdef CONFIG_HPET_EMULATE_RTC
+		!(id & HPET_ID_NUMBER) ||
+#endif
 	    !(id & HPET_ID_LEGSUP))
 		return -1;
 
_
